@@ -182,7 +182,7 @@ async def test_agen_protection():
         agen_unprotected1,
         agen_unprotected2,
     ]:
-        async for _ in agen_fn():
+        async for _ in agen_fn():  # noqa
             assert not _core.currently_ki_protected()
 
         # asynccontextmanager insists that the function passed must itself be an
@@ -581,11 +581,11 @@ def test_ki_wakes_us_up():
             print("joining thread", sys.exc_info())
             thread.join()
 
-    start = time.monotonic()
+    start = time.perf_counter()
     try:
         _core.run(main)
     finally:
-        end = time.monotonic()
+        end = time.perf_counter()
         print("duration", end - start)
         print("sys.exc_info", sys.exc_info())
     assert 1.0 <= (end - start) < 2
