@@ -196,11 +196,6 @@ class CapacityLimiter:
         """
         return self._total_tokens
 
-    def _wake_waiters(self):
-        available = self._total_tokens - len(self._borrowers)
-        for woken in self._lot.unpark(count=available):
-            self._borrowers.add(self._pending_borrowers.pop(woken))
-
     @total_tokens.setter
     def total_tokens(self, new_total_tokens):
         if not isinstance(new_total_tokens, int):
@@ -210,6 +205,11 @@ class CapacityLimiter:
         self._total_tokens = new_total_tokens
         self._wake_waiters()
 
+    def _wake_waiters(self):
+        available = self._total_tokens - len(self._borrowers)
+        for woken in self._lot.unpark(count=available):
+            self._borrowers.add(self._pending_borrowers.pop(woken))
+
     @property
     def borrowed_tokens(self):
         """The amount of capacity that's currently in use.
@@ -415,8 +415,9 @@ class Semaphore:
         else:
             max_value_str = ", max_value={}".format(self._max_value)
         return (
-            "<trio.Semaphore({}{}) at {:#x}>"
-            .format(self._value, max_value_str, id(self))
+            "<trio.Semaphore({}{}) at {:#x}>".format(
+                self._value, max_value_str, id(self)
+            )
         )
 
     @property
@@ -524,8 +525,9 @@ class Lock:
             s1 = "unlocked"
             s2 = ""
         return (
-            "<{} {} object at {:#x}{}>"
-            .format(s1, self.__class__.__name__, id(self), s2)
+            "<{} {} object at {:#x}{}>".format(
+                s1, self.__class__.__name__, id(self), s2
+            )
         )
 
     def locked(self):
@@ -607,7 +609,7 @@ class Lock:
 
 
 class StrictFIFOLock(Lock):
-    """A variant of :class:`Lock` where tasks are guaranteed to acquire the
+    r"""A variant of :class:`Lock` where tasks are guaranteed to acquire the
     lock in strict first-come-first-served order.
 
     An example of when this is useful is if you're implementing something like
@@ -791,7 +793,7 @@ class Condition:
         self._lot.repark_all(self._lock._lot)
 
     def statistics(self):
-        """Return an object containing debugging information.
+        r"""Return an object containing debugging information.
 
         Currently the following fields are defined:
 
@@ -858,8 +860,9 @@ class Queue:
 
     def __repr__(self):
         return (
-            "<Queue({}) at {:#x} holding {} items>"
-            .format(self.capacity, id(self), len(self._data))
+            "<Queue({}) at {:#x} holding {} items>".format(
+                self.capacity, id(self), len(self._data)
+            )
         )
 
     def qsize(self):
